@@ -552,6 +552,7 @@ InfomapBase& InfomapBase::initTree(const NodePaths& tree)
 
 	}
 	aggregateFlowValuesFromLeafToRoot();
+	initNetwork();
 
 	m_hierarchicalCodelength = calcCodelengthOnTree(true);
 	Log(4) << " => " << maxDepth << " levels with codelength: " << m_hierarchicalCodelength << "\n";
@@ -2080,7 +2081,7 @@ std::string InfomapBase::getOutputFileHeader()
 		"# started at " << m_startDate << "\n" <<
 		"# completed in " << m_elapsedTime.getElapsedTimeInSec() << " s\n" <<
 		"# codelength " << codelength() << " bits\n" <<
-		"# relative codelength savings " << getRelativeCodelengthSavings() << "%";
+		"# relative codelength savings " << getRelativeCodelengthSavings() * 100 << "%";
 }
 
 std::string InfomapBase::writeTree(std::string filename, bool states)
